[libchamplain] Update GtkDoc and remove deprecated symbols introduced in 0.3 and never released
- From: Pierre-Luc Beaudoin <plbeaudoin src gnome org>
- To: svn-commits-list gnome org
- Cc:
- Subject: [libchamplain] Update GtkDoc and remove deprecated symbols introduced in 0.3 and never released
- Date: Mon, 14 Sep 2009 17:31:12 +0000 (UTC)
commit 0566060709b5ec025f1e85532e46316f375a0def
Author: Pierre-Luc Beaudoin <pierre-luc pierlux com>
Date: Mon Sep 14 13:30:09 2009 -0400
Update GtkDoc and remove deprecated symbols introduced in 0.3 and never released
NEWS | 5 +-
champlain/champlain-base-marker.c | 4 +-
champlain/champlain-cache.c | 15 +----
champlain/champlain-cache.h | 1 -
champlain/champlain-layer.c | 2 +-
champlain/champlain-map-source-desc.c | 4 +-
champlain/champlain-map-source-desc.h | 14 ++++
champlain/champlain-map-source-factory.c | 21 ++-----
champlain/champlain-map-source-factory.h | 4 +-
champlain/champlain-map-source.c | 28 ++++----
champlain/champlain-marker.c | 37 ++++++------
champlain/champlain-network-map-source.c | 11 +---
champlain/champlain-network-map-source.h | 3 -
champlain/champlain-polygon.c | 80 ++++++++++++------------
champlain/champlain-polygon.h | 2 +-
champlain/champlain-selection-layer.c | 65 +++++++++++++++++---
champlain/champlain-tile.c | 31 +++++-----
champlain/champlain-view.c | 38 +++++++----
champlain/champlain-zoom-level.c | 14 ++--
docs/reference-gtk/libchamplain-gtk-docs.sgml | 27 ++++++++-
docs/reference/libchamplain-docs.sgml | 4 +-
docs/reference/libchamplain-sections.txt | 17 ++---
docs/reference/libchamplain.types | 1 +
23 files changed, 246 insertions(+), 182 deletions(-)
---
diff --git a/NEWS b/NEWS
index 3a6903d..1694a45 100644
--- a/NEWS
+++ b/NEWS
@@ -16,9 +16,12 @@ Fixes:
* Get rid of black lines between tiles at high zoom levels
(Pierre-Luc Beaudoin)
* Fix polygon not visible at higher zoom levels (Pierre-Luc Beaudoin)
-* 594963: Initial scrolling results in map being in Antarctica (Pierre-Luc Beaudoin)
+* 594963: Initial scrolling results in map being in Antarctica
+ (Pierre-Luc Beaudoin)
* Make default selection mode in ChamplainSelectionMode single to match Gtk+
(Pierre-Luc Beaudoin)
+* Remove deprecated symbols introduced in 0.3 and removed in 0.3
+ (Pierre-Luc Beaudoin)
libchamplain 0.3.92 (2009-09-03)
===============================
diff --git a/champlain/champlain-base-marker.c b/champlain/champlain-base-marker.c
index 05dfad4..51f7992 100644
--- a/champlain/champlain-base-marker.c
+++ b/champlain/champlain-base-marker.c
@@ -200,7 +200,7 @@ champlain_base_marker_init (ChamplainBaseMarker *marker)
/**
* champlain_base_marker_new:
*
- * Returns a new #ChamplainBaseMarker ready to be used as a #ClutterActor.
+ * Returns: a new #ChamplainBaseMarker ready to be used as a #ClutterActor.
*
* Since: 0.4
*/
@@ -268,7 +268,7 @@ champlain_base_marker_set_highlighted (ChamplainBaseMarker *champlainBaseMarker,
* champlain_base_marker_get_highlighted:
* @marker: a #ChamplainBaseMarker
*
- * Returns the highlighted or not state of the marker.
+ * Returns: the highlighted or not state of the marker.
*
* Since: 0.4
*/
diff --git a/champlain/champlain-cache.c b/champlain/champlain-cache.c
index d722b19..8c9e5ba 100644
--- a/champlain/champlain-cache.c
+++ b/champlain/champlain-cache.c
@@ -280,7 +280,7 @@ cleanup:
/**
* champlain_cache_dup_default:
*
- * Returns the #ChamplainCache singleton, use #g_object_unref when not neeeded
+ * Returns: the #ChamplainCache singleton, use #g_object_unref when not neeeded
* anymore.
*
*
@@ -292,17 +292,11 @@ champlain_cache_dup_default (void)
return g_object_new (CHAMPLAIN_TYPE_CACHE, NULL);
}
-ChamplainCache*
-champlain_cache_get_default (void)
-{
- return champlain_cache_dup_default ();
-}
-
/**
* champlain_cache_get_size_limit:
* @self: the #ChamplainCache
*
- * Returns the cache size limit in bytes
+ * Returns: the cache size limit in bytes
*
* Since: 0.4
*/
@@ -344,7 +338,7 @@ champlain_cache_set_size_limit (ChamplainCache *self,
*
* Loads data from disk for the given tile
*
- * Returns TRUE if the tile was in cache, false if it needs to be
+ * Returns: TRUE if the tile was in cache, false if it needs to be
* loaded from network
*
* Since: 0.4
@@ -447,8 +441,7 @@ cleanup:
* @self: the #ChamplainCache
* @tile: the #ChamplainTile to fill
*
- * Returns TRUE if the tile should be
- * reloaded from network
+ * Returns: TRUE if the tile should be reloaded from network, FALSE otherwize.
*
* Since: 0.4
*/
diff --git a/champlain/champlain-cache.h b/champlain/champlain-cache.h
index e0ff236..818aa76 100644
--- a/champlain/champlain-cache.h
+++ b/champlain/champlain-cache.h
@@ -55,7 +55,6 @@ typedef struct {
GType champlain_cache_get_type (void);
ChamplainCache* champlain_cache_dup_default (void);
-ChamplainCache* champlain_cache_get_default (void) G_GNUC_DEPRECATED;
void champlain_cache_update_tile (ChamplainCache *self,
ChamplainTile *tile,
diff --git a/champlain/champlain-layer.c b/champlain/champlain-layer.c
index d11e901..b3d7191 100644
--- a/champlain/champlain-layer.c
+++ b/champlain/champlain-layer.c
@@ -182,7 +182,7 @@ layer_remove_cb (ClutterGroup *layer,
/**
* champlain_layer_new:
*
- * Returns a new #ChamplainLayer ready to be used as a #ClutterContainer for the markers.
+ * Returns: a new #ChamplainLayer ready to be used as a #ClutterContainer for the markers.
*
* Since: 0.2.2
*/
diff --git a/champlain/champlain-map-source-desc.c b/champlain/champlain-map-source-desc.c
index 58cc305..161492c 100644
--- a/champlain/champlain-map-source-desc.c
+++ b/champlain/champlain-map-source-desc.c
@@ -119,10 +119,8 @@ champlain_map_source_desc_free (ChamplainMapSourceDesc *desc)
/**
* champlain_map_source_desc_new:
- * @lat: the latitude
- * @lon: the longitude
*
- * Return value: a newly allocated #ChamplainMapSourceDesc to be freed with #champlain_map_source_desc_free
+ * Returns: a newly allocated #ChamplainMapSourceDesc to be freed with #champlain_map_source_desc_free
*
* Since: 0.4
*/
diff --git a/champlain/champlain-map-source-desc.h b/champlain/champlain-map-source-desc.h
index 949a14e..6b4d107 100644
--- a/champlain/champlain-map-source-desc.h
+++ b/champlain/champlain-map-source-desc.h
@@ -34,10 +34,14 @@ typedef struct _ChamplainMapSourceDesc ChamplainMapSourceDesc;
/**
* ChamplainMapSourceConstructor:
+ * @desc: a #ChamplainMapSourceDesc
+ * @data: User data
*
* A #ChamplainMapSource constructor. It should return a ready to use
* #ChamplainMapSource.
*
+ * Returns: A fully constructed #ChamplainMapSource ready to be used.
+ *
* Since: 0.4
*/
typedef ChamplainMapSource * (*ChamplainMapSourceConstructor) (
@@ -48,6 +52,16 @@ typedef ChamplainMapSource * (*ChamplainMapSourceConstructor) (
/**
* ChamplainMapSourceDesc:
+ * @id: A unique identifier, should contain only characters found in filenames
+ * @name: A display name
+ * @license: A display name for the licence of the data
+ * @license_uri: A URI for the licence of the data
+ * @min_zoom_level: the minimum supported zoom level
+ * @max_zoom_level: the maximum supported zoom level
+ * @projection: the projection used by the data
+ * @uri_format: the URI to use to fetch network map data
+ * @constructor: a function that returns a fully constructed #ChamplainMapSource
+ * @data: user data passed to the constructor
*
* Describes a #ChamplainMapSource. This is returned by #champlain_map_source_factory_get_list.
*
diff --git a/champlain/champlain-map-source-factory.c b/champlain/champlain-map-source-factory.c
index 1742f24..5199ba2 100644
--- a/champlain/champlain-map-source-factory.c
+++ b/champlain/champlain-map-source-factory.c
@@ -276,7 +276,7 @@ champlain_map_source_factory_init (ChamplainMapSourceFactory *factory)
/**
* champlain_map_source_factory_dup_default:
*
- * Returns the singleton #ChamplainMapSourceFactory, it should be freed
+ * Returns: the singleton #ChamplainMapSourceFactory, it should be freed
* using #g_object_unref when not needed.
*
* Since: 0.4
@@ -287,16 +287,10 @@ champlain_map_source_factory_dup_default (void)
return g_object_new (CHAMPLAIN_TYPE_MAP_SOURCE_FACTORY, NULL);
}
-ChamplainMapSourceFactory *
-champlain_map_source_factory_get_default (void)
-{
- return champlain_map_source_factory_dup_default ();
-}
-
/**
* champlain_map_source_factory_dup_list:
*
- * Returns the list of registered map sources, the items should not be freed,
+ * Returns: the list of registered map sources, the items should not be freed,
* the list should be freed with #g_slist_free.
*
* Since: 0.4
@@ -307,18 +301,12 @@ champlain_map_source_factory_dup_list (ChamplainMapSourceFactory *factory)
return g_slist_copy (factory->priv->registered_sources);
}
-GSList *
-champlain_map_source_factory_get_list (ChamplainMapSourceFactory *factory)
-{
- return champlain_map_source_factory_dup_list (factory);
-}
-
/**
* champlain_map_source_factory_create:
* @factory: the Factory
* @id: the wanted map source id
*
- * Returns a ready to use #ChamplainMapSource matching the given name, returns
+ * Returns: a ready to use #ChamplainMapSource matching the given name, returns
* NULL is none match.
*
* The id should not contain any character that can't be in a filename as it
@@ -346,6 +334,7 @@ champlain_map_source_factory_create (ChamplainMapSourceFactory *factory,
/**
* champlain_map_source_factory_register:
+ * @factory: A #ChamplainMapSourceFactory
* @desc: the description of the map source
* @constructor: the new map source constructor function
* @data: data to be passed to the constructor function, or NULL
@@ -356,7 +345,7 @@ champlain_map_source_factory_create (ChamplainMapSourceFactory *factory,
* #ChamplainMapSourceDesc, so don't free it. They will not be freed either so
* you can use static structs here.
*
- * Returns TRUE if the registration suceeded.
+ * Returns: TRUE if the registration suceeded.
*
* Since: 0.4
*/
diff --git a/champlain/champlain-map-source-factory.h b/champlain/champlain-map-source-factory.h
index 14470c7..49226e9 100644
--- a/champlain/champlain-map-source-factory.h
+++ b/champlain/champlain-map-source-factory.h
@@ -56,10 +56,8 @@ struct _ChamplainMapSourceFactoryClass
GType champlain_map_source_factory_get_type (void);
ChamplainMapSourceFactory * champlain_map_source_factory_dup_default (void);
-ChamplainMapSourceFactory * champlain_map_source_factory_get_default (void) G_GNUC_DEPRECATED;
GSList * champlain_map_source_factory_dup_list (ChamplainMapSourceFactory *factory);
-GSList * champlain_map_source_factory_get_list (ChamplainMapSourceFactory *factory) G_GNUC_DEPRECATED;
ChamplainMapSource * champlain_map_source_factory_create (ChamplainMapSourceFactory *factory,
const gchar *id);
@@ -67,7 +65,7 @@ ChamplainMapSource * champlain_map_source_factory_create (ChamplainMapSourceFact
gboolean
champlain_map_source_factory_register (ChamplainMapSourceFactory *factory,
ChamplainMapSourceDesc *desc, ChamplainMapSourceConstructor constructor,
- gpointer user_data);
+ gpointer data);
#define CHAMPLAIN_MAP_SOURCE_OSM_MAPNIK "osm-mapnik"
#define CHAMPLAIN_MAP_SOURCE_OSM_OSMARENDER "osm-osmarender"
diff --git a/champlain/champlain-map-source.c b/champlain/champlain-map-source.c
index 2022fd2..47a28cc 100644
--- a/champlain/champlain-map-source.c
+++ b/champlain/champlain-map-source.c
@@ -334,7 +334,7 @@ champlain_map_source_init (ChamplainMapSource *champlainMapSource)
* champlain_map_source_get_max_zoom_level:
* @map_source: a #ChamplainMapSource
*
- * Returns the maximum zoom level this map source supports
+ * Returns: the maximum zoom level this map source supports
*
* Since: 0.4
*/
@@ -351,7 +351,7 @@ champlain_map_source_get_max_zoom_level (ChamplainMapSource *map_source)
* champlain_map_source_get_min_zoom_level:
* @map_source: a #ChamplainMapSource
*
- * Returns the miminum zoom level this map source supports
+ * Returns: the miminum zoom level this map source supports
*
* Since: 0.4
*/
@@ -368,7 +368,7 @@ champlain_map_source_get_min_zoom_level (ChamplainMapSource *map_source)
* champlain_map_source_get_tile_size:
* @map_source: a #ChamplainMapSource
*
- * Returns the tile's size (width and height) in pixels for this map source
+ * Returns: the tile's size (width and height) in pixels for this map source
*
* Since: 0.4
*/
@@ -387,7 +387,7 @@ champlain_map_source_get_tile_size (ChamplainMapSource *map_source)
* @zoom_level: the zoom level
* @longitude: a longitude
*
- * Returns the x position on the map using this map source's projection.
+ * Returns: the x position on the map using this map source's projection.
* (0, 0) is located at the top left.
*
* Since: 0.4
@@ -410,7 +410,7 @@ champlain_map_source_get_x (ChamplainMapSource *map_source,
* @zoom_level: the zoom level
* @latitude: a latitude
*
- * Returns the y position on the map using this map source's projection.
+ * Returns: the y position on the map using this map source's projection.
* (0, 0) is located at the top left.
*
* Since: 0.4
@@ -434,7 +434,7 @@ champlain_map_source_get_y (ChamplainMapSource *map_source,
* @map_source: a #ChamplainMapSource
* @zoom_level: the zoom level
*
- * Returns the number of tiles in a row at this zoom level for this map source.
+ * Returns: the number of tiles in a row at this zoom level for this map source.
*
* Since: 0.4
*/
@@ -454,7 +454,7 @@ champlain_map_source_get_row_count (ChamplainMapSource *map_source,
* @map_source: a #ChamplainMapSource
* @zoom_level: the zoom level
*
- * Returns the number of tiles in a column at this zoom level for this map
+ * Returns: the number of tiles in a column at this zoom level for this map
* source.
*
* Since: 0.4
@@ -495,7 +495,7 @@ champlain_map_source_fill_tile (ChamplainMapSource *map_source,
* @zoom_level: the zoom level
* @x: a x position
*
- * Returns the longitude corresponding to this x position in the map source's
+ * Returns: the longitude corresponding to this x position in the map source's
* projection.
*
* Since: 0.4
@@ -518,7 +518,7 @@ champlain_map_source_get_longitude (ChamplainMapSource *map_source,
* @zoom_level: the zoom level
* @y: a y position
*
- * Returns the latitude corresponding to this y position in the map source's
+ * Returns: the latitude corresponding to this y position in the map source's
* projection.
*
* Since: 0.4
@@ -540,7 +540,7 @@ champlain_map_source_get_latitude (ChamplainMapSource *map_source,
* champlain_map_source_get_name:
* @map_source: a #ChamplainMapSource
*
- * Returns the map source's name.
+ * Returns: the map source's name.
*
* Since: 0.4
*/
@@ -579,7 +579,7 @@ champlain_map_source_set_name (ChamplainMapSource *map_source,
* champlain_map_source_get_license:
* @map_source: a #ChamplainMapSource
*
- * Returns the map source's license.
+ * Returns: the map source's license.
*
* Since: 0.4
*/
@@ -618,7 +618,7 @@ champlain_map_source_set_license (ChamplainMapSource *map_source,
* champlain_map_source_get_license_uri:
* @map_source: a #ChamplainMapSource
*
- * Returns the map source's license URI.
+ * Returns: the map source's license URI.
*
* Since: 0.4
*/
@@ -658,7 +658,7 @@ champlain_map_source_set_license_uri (ChamplainMapSource *map_source,
* champlain_map_source_get_projection:
* @map_source: a #ChamplainMapSource
*
- * Returns the map source's projection.
+ * Returns: the map source's projection.
*
* Since: 0.4
*/
@@ -695,7 +695,7 @@ champlain_map_source_set_projection (ChamplainMapSource *map_source,
* champlain_map_source_get_id:
* @map_source: a #ChamplainMapSource
*
- * Returns the map source's id.
+ * Returns: the map source's id.
*
* Since: 0.4
*/
diff --git a/champlain/champlain-marker.c b/champlain/champlain-marker.c
index ec0a228..a511e26 100644
--- a/champlain/champlain-marker.c
+++ b/champlain/champlain-marker.c
@@ -118,10 +118,11 @@ static void queue_redraw (ChamplainMarker *marker);
* champlain_marker_set_hightlight_color:
* @color: a #ClutterColor
*
+ *
* Changes the highlight color, this is to ensure a better integration with
* the desktop, this is automatically done by GtkChamplainEmbed.
*
- * Since: 0.2
+ * Since: 0.4
*/
void
champlain_marker_set_highlight_color (ClutterColor *color)
@@ -713,7 +714,7 @@ champlain_marker_init (ChamplainMarker *marker)
/**
* champlain_marker_new:
*
- * Returns a new #ChamplainMarker ready to be used as a #ClutterActor.
+ * Returns: a new #ChamplainMarker ready to be used as a #ClutterActor.
*
* Since: 0.2
*/
@@ -730,7 +731,7 @@ champlain_marker_new (void)
* @text_color: a #ClutterColor, the color of the text, can be NULL
* @marker_color: a #ClutterColor, the color of the marker, can be NULL
*
- * Returns a new #ChamplainMarker with a drawn marker containing the given text.
+ * Returns: a new #ChamplainMarker with a drawn marker containing the given text.
*
* Since: 0.2
*/
@@ -760,7 +761,7 @@ champlain_marker_new_with_text (const gchar *text,
* champlain_marker_new_with_image:
* @actor: The actor of the image.
*
- * Returns a new #ChamplainMarker with a drawn marker containing the given
+ * Returns: a new #ChamplainMarker with a drawn marker containing the given
* image.
*
* Since: 0.4
@@ -782,7 +783,7 @@ champlain_marker_new_with_image (ClutterActor *actor)
* @filename: The filename of the image.
* @error: Return location for an error.
*
- * Returns a new #ChamplainMarker with a drawn marker containing the given
+ * Returns: a new #ChamplainMarker with a drawn marker containing the given
* image.
*
* Since: 0.4
@@ -810,7 +811,7 @@ champlain_marker_new_from_file (const gchar *filename,
* @text: The text
* @actor: The image
*
- * Returns a new #ChamplainMarker with a drawn marker containing the given
+ * Returns: a new #ChamplainMarker with a drawn marker containing the given
* image.
*
* Since: 0.4
@@ -1159,7 +1160,7 @@ champlain_marker_set_draw_background (ChamplainMarker *marker,
* champlain_marker_get_image:
* @marker: The marker
*
- * Returns the marker's image.
+ * Returns: the marker's image.
*
* Since: 0.4
*/
@@ -1177,7 +1178,7 @@ champlain_marker_get_image (ChamplainMarker *marker)
* champlain_marker_get_use_markup:
* @marker: The marker
*
- * Returns if the marker's text contains markup.
+ * Returns: if the marker's text contains markup.
*
* Since: 0.4
*/
@@ -1195,7 +1196,7 @@ champlain_marker_get_use_markup (ChamplainMarker *marker)
* champlain_marker_get_text:
* @marker: The marker
*
- * Returns the marker's text.
+ * Returns: the marker's text.
*
* Since: 0.4
*/
@@ -1213,7 +1214,7 @@ champlain_marker_get_text (ChamplainMarker *marker)
* champlain_marker_get_alignment:
* @marker: The marker
*
- * Returns the marker's text alignment.
+ * Returns: the marker's text alignment.
*
* Since: 0.4
*/
@@ -1231,7 +1232,7 @@ champlain_marker_get_alignment (ChamplainMarker *marker)
* champlain_marker_get_color:
* @marker: The marker
*
- * Returns the marker's color.
+ * Returns: the marker's color.
*
* Since: 0.4
*/
@@ -1249,7 +1250,7 @@ champlain_marker_get_color (ChamplainMarker *marker)
* champlain_marker_get_text_color:
* @marker: The marker
*
- * Returns the marker's text color.
+ * Returns: the marker's text color.
*
* Since: 0.4
*/
@@ -1267,7 +1268,7 @@ champlain_marker_get_text_color (ChamplainMarker *marker)
* champlain_marker_get_font_name:
* @marker: The marker
*
- * Returns the marker's font name.
+ * Returns: the marker's font name.
*
* Since: 0.4
*/
@@ -1285,7 +1286,7 @@ champlain_marker_get_font_name (ChamplainMarker *marker)
* champlain_marker_get_wrap:
* @marker: The marker
*
- * Returns if the marker's text wraps.
+ * Returns: if the marker's text wraps.
*
* Since: 0.4
*/
@@ -1303,7 +1304,7 @@ champlain_marker_get_wrap (ChamplainMarker *marker)
* champlain_marker_get_wrap_mode:
* @marker: The marker
*
- * Returns the marker's text wrap mode.
+ * Returns: the marker's text wrap mode.
*
* Since: 0.4
*/
@@ -1321,7 +1322,7 @@ champlain_marker_get_wrap_mode (ChamplainMarker *marker)
* champlain_marker_get_ellipsize:
* @marker: The marker
*
- * Returns the marker's text ellipsize mode.
+ * Returns: the marker's text ellipsize mode.
*
* Since: 0.4
*/
@@ -1339,7 +1340,7 @@ champlain_marker_get_ellipsize (ChamplainMarker *marker)
* champlain_marker_get_single_line_mode:
* @marker: The marker
*
- * Returns the marker's text single side mode.
+ * Returns: the marker's text single side mode.
*
* Since: 0.4
*/
@@ -1357,7 +1358,7 @@ champlain_marker_get_single_line_mode (ChamplainMarker *marker)
* champlain_marker_get_draw_background:
* @marker: The marker
*
- * Returns if the marker's has a background.
+ * Returns: if the marker's has a background.
*
* Since: 0.4
*/
diff --git a/champlain/champlain-network-map-source.c b/champlain/champlain-network-map-source.c
index de33c61..8abbfbf 100644
--- a/champlain/champlain-network-map-source.c
+++ b/champlain/champlain-network-map-source.c
@@ -252,7 +252,7 @@ champlain_network_map_source_init (ChamplainNetworkMapSource *champlainMapSource
* @projection: the map source's projection
* @uri_format: the URI to fetch the tiles from, see #champlain_network_map_source_set_uri_format
*
- * Returns a constructed #ChamplainNetworkMapSource
+ * Returns: a constructed #ChamplainNetworkMapSource
*
* Since: 0.4
*/
@@ -283,7 +283,7 @@ champlain_network_map_source_new_full (const gchar *id,
* @y: the y position of the tile
* @z: the zool level of the tile
*
- * Returns a contruscted URI with the given parameters based on the map
+ * Returns: a contruscted URI with the given parameters based on the map
* source's URI format.
*
* Since: 0.4
@@ -672,10 +672,3 @@ fill_tile (ChamplainMapSource *map_source,
*/
g_object_unref (cache);
}
-
-void
-champlain_network_map_source_fill_tile (ChamplainMapSource *map_source,
- ChamplainTile *tile)
-{
- fill_tile (map_source, tile);
-}
diff --git a/champlain/champlain-network-map-source.h b/champlain/champlain-network-map-source.h
index 9cce198..cb06422 100644
--- a/champlain/champlain-network-map-source.h
+++ b/champlain/champlain-network-map-source.h
@@ -72,9 +72,6 @@ gchar * champlain_network_map_source_get_tile_uri (ChamplainNetworkMapSource *so
void champlain_network_map_source_set_uri_format (ChamplainNetworkMapSource *source,
const gchar *uri_format);
-void champlain_network_map_source_fill_tile (ChamplainMapSource *map_source,
- ChamplainTile *tile) G_GNUC_DEPRECATED;
-
G_END_DECLS
#endif
diff --git a/champlain/champlain-polygon.c b/champlain/champlain-polygon.c
index 6ca6545..3355cff 100644
--- a/champlain/champlain-polygon.c
+++ b/champlain/champlain-polygon.c
@@ -272,24 +272,24 @@ champlain_polygon_class_init (ChamplainPolygonClass *klass)
}
static void
-champlain_polygon_init (ChamplainPolygon *self)
+champlain_polygon_init (ChamplainPolygon *polygon)
{
- self->priv = GET_PRIVATE (self);
+ polygon->priv = GET_PRIVATE (polygon);
- self->priv->visible = TRUE;
- self->priv->points = NULL;
- self->priv->fill = FALSE;
- self->priv->stroke = TRUE;
- self->priv->stroke_width = 2.0;
+ polygon->priv->visible = TRUE;
+ polygon->priv->points = NULL;
+ polygon->priv->fill = FALSE;
+ polygon->priv->stroke = TRUE;
+ polygon->priv->stroke_width = 2.0;
- self->priv->fill_color = clutter_color_copy (&DEFAULT_FILL_COLOR);
- self->priv->stroke_color = clutter_color_copy (&DEFAULT_STROKE_COLOR);
+ polygon->priv->fill_color = clutter_color_copy (&DEFAULT_FILL_COLOR);
+ polygon->priv->stroke_color = clutter_color_copy (&DEFAULT_STROKE_COLOR);
}
/**
* champlain_polygon_new:
*
- * Returns a new empty #ChamplainPolygon
+ * Returns: a new empty #ChamplainPolygon
*
* Since: 0.4
*/
@@ -307,21 +307,21 @@ champlain_polygon_new ()
*
* Adds point at the end of the list of points in the polygon
*
- * Returns the added point, should not be freed.
+ * Returns: the added point, should not be freed.
*
* Since: 0.4
*/
ChamplainPoint *
-champlain_polygon_append_point (ChamplainPolygon *self,
+champlain_polygon_append_point (ChamplainPolygon *polygon,
gdouble lat,
gdouble lon)
{
- g_return_val_if_fail (CHAMPLAIN_IS_POLYGON (self), NULL);
+ g_return_val_if_fail (CHAMPLAIN_IS_POLYGON (polygon), NULL);
ChamplainPoint *point = champlain_point_new (lat, lon);
- self->priv->points = g_list_append (self->priv->points, point);
- g_object_notify (G_OBJECT (self), "visible");
+ polygon->priv->points = g_list_append (polygon->priv->points, point);
+ g_object_notify (G_OBJECT (polygon), "visible");
return point;
}
@@ -334,28 +334,28 @@ champlain_polygon_append_point (ChamplainPolygon *self,
*
* Adds point at the given position in the list of points in the polygon
*
- * Returns the added point, should not be freed.
+ * Returns: the added point, should not be freed.
*
* Since: 0.4
*/
ChamplainPoint *
-champlain_polygon_insert_point (ChamplainPolygon *self,
+champlain_polygon_insert_point (ChamplainPolygon *polygon,
gdouble lat,
gdouble lon,
gint pos)
{
- g_return_val_if_fail (CHAMPLAIN_IS_POLYGON (self), NULL);
+ g_return_val_if_fail (CHAMPLAIN_IS_POLYGON (polygon), NULL);
ChamplainPoint *point = champlain_point_new (lat, lon);
- self->priv->points = g_list_insert (self->priv->points, point, pos);
- g_object_notify (G_OBJECT (self), "visible");
+ polygon->priv->points = g_list_insert (polygon->priv->points, point, pos);
+ g_object_notify (G_OBJECT (polygon), "visible");
return point;
}
/**
* champlain_polygon_remove_point:
- * @polygon: The polygon
+ * @polygon: a #ChamplainPolygon
* @point: the #ChamplainPoint to remove
*
* Removes the point from the polygon.
@@ -363,13 +363,13 @@ champlain_polygon_insert_point (ChamplainPolygon *self,
* Since: 0.4
*/
void
-champlain_polygon_remove_point (ChamplainPolygon *self,
+champlain_polygon_remove_point (ChamplainPolygon *polygon,
ChamplainPoint *point)
{
- g_return_if_fail (CHAMPLAIN_IS_POLYGON (self));
+ g_return_if_fail (CHAMPLAIN_IS_POLYGON (polygon));
- self->priv->points = g_list_remove (self->priv->points, point);
- g_object_notify (G_OBJECT (self), "visible");
+ polygon->priv->points = g_list_remove (polygon->priv->points, point);
+ g_object_notify (G_OBJECT (polygon), "visible");
}
/**
@@ -381,35 +381,35 @@ champlain_polygon_remove_point (ChamplainPolygon *self,
* Since: 0.4
*/
void
-champlain_polygon_clear_points (ChamplainPolygon *self)
+champlain_polygon_clear_points (ChamplainPolygon *polygon)
{
- g_return_if_fail (CHAMPLAIN_IS_POLYGON (self));
+ g_return_if_fail (CHAMPLAIN_IS_POLYGON (polygon));
- GList *next = self->priv->points;
+ GList *next = polygon->priv->points;
while (next != NULL)
{
champlain_point_free (next->data);
next = g_list_next (next);
}
- g_list_free (self->priv->points);
- self->priv->points = NULL;
- g_object_notify (G_OBJECT (self), "visible");
+ g_list_free (polygon->priv->points);
+ polygon->priv->points = NULL;
+ g_object_notify (G_OBJECT (polygon), "visible");
}
/**
* champlain_polygon_get_points:
* @polygon: The polygon
*
- * Returns a list of all points from the polygon, it shouldn't be freed.
+ * Returns: a list of all points from the polygon, it shouldn't be freed.
*
* Since: 0.4
*/
GList *
-champlain_polygon_get_points (ChamplainPolygon *self)
+champlain_polygon_get_points (ChamplainPolygon *polygon)
{
- g_return_val_if_fail (CHAMPLAIN_IS_POLYGON (self), NULL);
+ g_return_val_if_fail (CHAMPLAIN_IS_POLYGON (polygon), NULL);
- return self->priv->points;
+ return polygon->priv->points;
}
/**
@@ -472,7 +472,7 @@ champlain_polygon_set_stroke_color (ChamplainPolygon *polygon,
* champlain_polygon_get_color:
* @polygon: The polygon
*
- * Returns the polygon's fill color.
+ * Returns: the polygon's fill color.
*
* Since: 0.4
*/
@@ -488,7 +488,7 @@ champlain_polygon_get_fill_color (ChamplainPolygon *polygon)
* champlain_polygon_get_stroke_color:
* @polygon: The polygon
*
- * Returns the polygon's stroke color.
+ * Returns: the polygon's stroke color.
*
* Since: 0.4
*/
@@ -523,7 +523,7 @@ champlain_polygon_set_stroke (ChamplainPolygon *polygon,
* champlain_polygon_get_stroke:
* @polygon: The polygon
*
- * Returns if the polygon has a stroke
+ * Returns: TRUE if the polygon has a stroke, FALSE otherwise.
*
* Since: 0.4
*/
@@ -558,7 +558,7 @@ champlain_polygon_set_fill (ChamplainPolygon *polygon,
* champlain_polygon_get_fill:
* @polygon: The polygon
*
- * Returns if the polygon is filled
+ * Returns: TRUE if the polygon is filled, FALSE otherwise.
*
* Since: 0.4
*/
@@ -593,7 +593,7 @@ champlain_polygon_set_stroke_width (ChamplainPolygon *polygon,
* champlain_polygon_get_stroke_width:
* @polygon: The polygon
*
- * Returns the width of the stroke
+ * Returns: the width of the stroke
*
* Since: 0.4
*/
diff --git a/champlain/champlain-polygon.h b/champlain/champlain-polygon.h
index 27251c5..74d1269 100644
--- a/champlain/champlain-polygon.h
+++ b/champlain/champlain-polygon.h
@@ -69,7 +69,7 @@ ChamplainPoint * champlain_polygon_insert_point (ChamplainPolygon *polygon,
gdouble lat,
gdouble lon,
gint pos);
-void champlain_polygon_remove_point (ChamplainPolygon *self,
+void champlain_polygon_remove_point (ChamplainPolygon *polygon,
ChamplainPoint *point);
void champlain_polygon_clear_points (ChamplainPolygon *polygon);
GList *champlain_polygon_get_points (ChamplainPolygon *polygon);
diff --git a/champlain/champlain-tile.c b/champlain/champlain-tile.c
index b9a731a..c9c4d3b 100644
--- a/champlain/champlain-tile.c
+++ b/champlain/champlain-tile.c
@@ -401,7 +401,7 @@ champlain_tile_init (ChamplainTile *self)
/**
* champlain_tile_new:
*
- * Returns a new #ChamplainTile
+ * Returns: a new #ChamplainTile
*
* Since: 0.4
*/
@@ -415,7 +415,7 @@ champlain_tile_new (void)
* champlain_tile_get_x:
* @self: the #ChamplainTile
*
- * Returns the tile's x position
+ * Returns: the tile's x position
*
* Since: 0.4
*/
@@ -431,7 +431,7 @@ champlain_tile_get_x (ChamplainTile *self)
* champlain_tile_get_y:
* @self: the #ChamplainTile
*
- * Returns the tile's y position
+ * Returns: the tile's y position
*
* Since: 0.4
*/
@@ -447,7 +447,7 @@ champlain_tile_get_y (ChamplainTile *self)
* champlain_tile_get_zoom_level:
* @self: the #ChamplainTile
*
- * Returns the tile's zoom level
+ * Returns: the tile's zoom level
*
* Since: 0.4
*/
@@ -463,7 +463,7 @@ champlain_tile_get_zoom_level (ChamplainTile *self)
* champlain_tile_get_size:
* @self: the #ChamplainTile
*
- * Returns the tile's size in pixels
+ * Returns: the tile's size in pixels
*
* Since: 0.4
*/
@@ -479,7 +479,7 @@ champlain_tile_get_size (ChamplainTile *self)
* champlain_tile_get_state:
* @self: the #ChamplainTile
*
- * Returns the tile's #ChamplainState
+ * Returns: the tile's #ChamplainState
*
* Since: 0.4
*/
@@ -495,7 +495,7 @@ champlain_tile_get_state (ChamplainTile *self)
* champlain_tile_get_uri:
* @self: the #ChamplainTile
*
- * Returns the tile's remote uri
+ * Returns: the tile's remote uri
*
* Since: 0.4
*/
@@ -511,7 +511,7 @@ champlain_tile_get_uri (ChamplainTile *self)
* champlain_tile_get_filename:
* @self: the #ChamplainTile
*
- * Returns the tile's local filename
+ * Returns: the tile's local filename
*
* Since: 0.4
*/
@@ -527,7 +527,7 @@ champlain_tile_get_filename (ChamplainTile *self)
* champlain_tile_get_actor:
* @self: the #ChamplainTile
*
- * Returns the tile's actor. This actor should not change during the tile's
+ * Returns: the tile's actor. This actor should not change during the tile's
* lifetime. You should not unref this actor, it is owned by the tile.
*
* Since: 0.4
@@ -642,13 +642,12 @@ champlain_tile_set_state (ChamplainTile *self,
/**
* champlain_tile_new_full:
- * @self: the #ChamplainTile
* @x: the x position
* @y: the y position
* @size: the size in pixels
* @zoom_level: the zoom level
*
- * Returns a #ChamplainTile
+ * Returns: a #ChamplainTile
*
* Since: 0.4
*/
@@ -714,7 +713,7 @@ champlain_tile_set_filename (ChamplainTile *self,
* champlain_tile_get_modified_time:
* @self: the #ChamplainTile
*
- * Returns the tile's last modified time
+ * Returns: the tile's last modified time
*
* Since: 0.4
*/
@@ -729,7 +728,7 @@ champlain_tile_get_modified_time (ChamplainTile *self)
/**
* champlain_tile_set_modified_time:
* @self: the #ChamplainTile
- * @time_: a #GTimeVal, the value will be copied
+ * @time: a #GTimeVal, the value will be copied
*
* Sets the tile's modified time
*
@@ -752,7 +751,7 @@ champlain_tile_set_modified_time (ChamplainTile *self,
* champlain_tile_get_modified_time_string:
* @self: the #ChamplainTile
*
- * Returns the tile's modified time as a string (formated as per RFC 1123)
+ * Returns: the tile's modified time as a string (formated as per RFC 1123)
*
* Since: 0.4
*/
@@ -778,7 +777,7 @@ champlain_tile_get_modified_time_string (ChamplainTile *self)
* champlain_tile_get_etag:
* @self: the #ChamplainTile
*
- * Returns the tile's ETag
+ * Returns: the tile's ETag
*
* Since: 0.4
*/
@@ -901,7 +900,7 @@ champlain_tile_set_content (ChamplainTile *self,
/**
* champlain_tile_get_content:
*
- * Returns the tile's content, this actor will change each time the tile's content changes.
+ * Returns: the tile's content, this actor will change each time the tile's content changes.
* You should not unref this content, it is owned by the tile.
*
* Since: 0.4
diff --git a/champlain/champlain-view.c b/champlain/champlain-view.c
index 0e66a9d..53fb52a 100644
--- a/champlain/champlain-view.c
+++ b/champlain/champlain-view.c
@@ -923,7 +923,6 @@ champlain_view_class_init (ChamplainViewClass *champlainViewClass)
/**
* ChamplainView::animation-completed:
- * @view: the #ChamplainView that received the signal
*
* The ::animation-completed signal is emitted when any animation in the view
* ends. This is a detailed signal. For example, if you want to be signaled
@@ -1025,7 +1024,6 @@ champlain_view_init (ChamplainView *view)
clutter_container_add_actor (CLUTTER_CONTAINER (priv->viewport),
priv->map_layer);
-
g_signal_connect (priv->finger_scroll, "button-press-event",
G_CALLBACK (finger_scroll_button_press_cb), view);
g_signal_connect_after (priv->finger_scroll, "button-release-event",
@@ -1113,6 +1111,18 @@ viewport_pos_changed_cb (GObject *gobject,
g_object_notify (G_OBJECT (view), "latitude");
}
+/**
+ * champlain_view_set_size:
+ * @view: a #ChamplainView
+ * @width: the width in pixels
+ * @height: the height in pixels
+ *
+ * Sets the size of the view. This function will most probably be deprecated in
+ * future versions in favor of #clutter_actor_set_size. In the mean time, you need
+ * to call both.
+ *
+ * Since: 0.1
+ */
//FIXME: move to an handler of actor size change
void
champlain_view_set_size (ChamplainView *view,
@@ -1307,7 +1317,7 @@ finger_scroll_key_press_cb (ClutterActor *actor,
/**
* champlain_view_new:
*
- * Returns a new #ChamplainView ready to be used as a #ClutterActor.
+ * Returns: a new #ChamplainView ready to be used as a #ClutterActor.
*
* Since: 0.4
*/
@@ -1728,7 +1738,7 @@ champlain_view_add_layer (ChamplainView *view,
* @lat: a variable where to put the latitude of the event
* @lon: a variable where to put the longitude of the event
*
- * Returns the latitude, longitude coordinates for the given ClutterEvent.
+ * Returns: the latitude, longitude coordinates for the given ClutterEvent.
*
* Since: 0.2.8
*/
@@ -1791,7 +1801,7 @@ champlain_view_get_coords_from_event (ChamplainView *view,
* @lat: a variable where to put the latitude of the event
* @lon: a variable where to put the longitude of the event
*
- * Returns the latitude, longitude coordinates for the given x, y position in
+ * Returns: the latitude, longitude coordinates for the given x, y position in
* the view. Use if you get coordinates from GtkEvents for example.
*
* Since: 0.4
@@ -2389,7 +2399,7 @@ view_set_zoom_level_at (ChamplainView *view,
* champlain_view_get_zoom_level:
* @view: The view
*
- * Returns the view's current zoom level.
+ * Returns: the view's current zoom level.
*
* Since: 0.4
*/
@@ -2407,7 +2417,7 @@ champlain_view_get_zoom_level (ChamplainView *view)
* champlain_view_get_min_zoom_level:
* @view: The view
*
- * Returns the view's minimal zoom level allowed.
+ * Returns: the view's minimal zoom level allowed.
*
* Since: 0.4
*/
@@ -2425,7 +2435,7 @@ champlain_view_get_min_zoom_level (ChamplainView *view)
* champlain_view_get_max_zoom_level:
* @view: The view
*
- * Returns the view's maximal zoom level allowed.
+ * Returns: the view's maximal zoom level allowed.
*
* Since: 0.4
*/
@@ -2443,7 +2453,7 @@ champlain_view_get_max_zoom_level (ChamplainView *view)
* champlain_view_get_map_source:
* @view: The view
*
- * Returns the view's current map source. If you need to keep a reference to the
+ * Returns: the view's current map source. If you need to keep a reference to the
* map source then you have to call #g_object_ref.
*
* Since: 0.4
@@ -2462,7 +2472,7 @@ champlain_view_get_map_source (ChamplainView *view)
* champlain_view_get_decel_rate:
* @view: The view
*
- * Returns the view's deceleration rate.
+ * Returns: the view's deceleration rate.
*
* Since: 0.4
*/
@@ -2481,7 +2491,7 @@ champlain_view_get_decel_rate (ChamplainView *view)
* champlain_view_get_scroll_mode:
* @view: The view
*
- * Returns the view's scroll mode behaviour.
+ * Returns: the view's scroll mode behaviour.
*
* Since: 0.4
*/
@@ -2498,7 +2508,7 @@ champlain_view_get_scroll_mode (ChamplainView *view)
* champlain_view_get_keep_center_on_resize:
* @view: The view
*
- * Returns TRUE if the view keeps the center or resize.
+ * Returns: TRUE if the view keeps the center or resize, FALSE otherwise.
*
* Since: 0.4
*/
@@ -2515,7 +2525,7 @@ champlain_view_get_keep_center_on_resize (ChamplainView *view)
* champlain_view_get_show_license:
* @view: The view
*
- * Returns TRUE if the view displays the license.
+ * Returns: TRUE if the view displays the license, FALSE otherwise.
*
* Since: 0.4
*/
@@ -2532,7 +2542,7 @@ champlain_view_get_show_license (ChamplainView *view)
* champlain_view_get_zoom_on_double_click:
* @view: The view
*
- * Returns TRUE if the view zooms on double click.
+ * Returns: TRUE if the view zooms on double click, FALSE otherwise.
*
* Since: 0.4
*/
diff --git a/champlain/champlain-zoom-level.c b/champlain/champlain-zoom-level.c
index e9049aa..e7303fe 100644
--- a/champlain/champlain-zoom-level.c
+++ b/champlain/champlain-zoom-level.c
@@ -243,7 +243,7 @@ champlain_zoom_level_init (ChamplainZoomLevel *self)
/**
* champlain_zoom_level_new:
*
- * Returns a new ChamplainZoomLevel
+ * Returns: a new #ChamplainZoomLevel
*
* Since: 0.4
*/
@@ -303,7 +303,7 @@ champlain_zoom_level_remove_tile (ChamplainZoomLevel *self,
* champlain_zoom_level_tile_count:
* @self: a #ChamplainZoomLevel
*
- * Returns the number of tiles in a #ChamplainZoomLevel.
+ * Returns: the number of tiles in a #ChamplainZoomLevel.
*
* Since: 0.4
*/
@@ -320,7 +320,7 @@ champlain_zoom_level_tile_count (ChamplainZoomLevel *self)
* @self: a #ChamplainZoomLevel
* @index: an index
*
- * Returns the #ChamplainTile at given index
+ * Returns: the #ChamplainTile at given index
*
* Since: 0.4
*/
@@ -339,7 +339,7 @@ champlain_zoom_level_get_nth_tile (ChamplainZoomLevel *self,
* champlain_zoom_level_get_width:
* @self: a #ChamplainZoomLevel
*
- * Returns the absolute width of a #ChamplainZoomLevel in tiles
+ * Returns: the width of a #ChamplainZoomLevel in tiles
*
* Since: 0.4
*/
@@ -355,7 +355,7 @@ champlain_zoom_level_get_width (ChamplainZoomLevel *self)
* champlain_zoom_level_get_height:
* @self: a #ChamplainZoomLevel
*
- * Returns the absolute height of a #ChamplainZoomLevel in tiles
+ * Returns: the height of a #ChamplainZoomLevel in tiles
*
* Since: 0.4
*/
@@ -371,7 +371,7 @@ champlain_zoom_level_get_height (ChamplainZoomLevel *self)
* champlain_zoom_level_get_zoom_level:
* @self: a #ChamplainZoomLevel
*
- * Returns the zoom level of a #ChamplainZoomLevel
+ * Returns: the zoom level of a #ChamplainZoomLevel
*
* Since: 0.4
*/
@@ -447,7 +447,7 @@ champlain_zoom_level_set_zoom_level (ChamplainZoomLevel *self,
* champlain_zoom_level_get_actor:
* @self: a #ChamplainZoomLevel
*
- * Returns the #ClutterActor containing all the tiles of a #ChamplainZoomLevel,
+ * Returns: the #ClutterActor containing all the tiles of a #ChamplainZoomLevel,
* it should not be unref.
*
* Since: 0.4
diff --git a/docs/reference-gtk/libchamplain-gtk-docs.sgml b/docs/reference-gtk/libchamplain-gtk-docs.sgml
index 28fb85f..8d36313 100644
--- a/docs/reference-gtk/libchamplain-gtk-docs.sgml
+++ b/docs/reference-gtk/libchamplain-gtk-docs.sgml
@@ -9,8 +9,33 @@
<releaseinfo>
for libchamplain-gtk &version;
The latest version of this documentation can be found on-line at
- <ulink role="online-location" url="http://blog.pierlux.com/projects/libchamplain/">http://blog.pierlux.com/projects/libchamplain/</ulink>.
+ <ulink role="online-location" url="http://projects.gnome.org/libchamplain/">http://projects.gnome.org/libchamplain/</ulink>.
</releaseinfo>
+ <copyright>
+ <year>2008, 2009</year>
+ <holder>libchamplain contributors</holder>
+ </copyright>
+ <legalnotice>
+ <para>
+ Permission is granted to copy, distribute and/or modify this
+ document under the terms of the <citetitle>GNU Free
+ Documentation License</citetitle>, Version 1.1 or any later
+ version published by the Free Software Foundation with no
+ Invariant Sections, no Front-Cover Texts, and no Back-Cover
+ Texts. You may obtain a copy of the <citetitle>GNU Free
+ Documentation License</citetitle> from the Free Software
+ Foundation by visiting <ulink type="http"
+ url="http://www.fsf.org">their Web site</ulink> or by writing
+ to:
+
+ <address>
+ The Free Software Foundation, Inc.,
+ <street>59 Temple Place</street> - Suite 330,
+ <city>Boston</city>, <state>MA</state> <postcode>02111-1307</postcode>,
+ <country>USA</country>
+ </address>
+ </para>
+ </legalnotice>
</bookinfo>
<chapter>
diff --git a/docs/reference/libchamplain-docs.sgml b/docs/reference/libchamplain-docs.sgml
index 996c718..bdbbd66 100644
--- a/docs/reference/libchamplain-docs.sgml
+++ b/docs/reference/libchamplain-docs.sgml
@@ -12,8 +12,8 @@
<ulink role="online-location" url="http://projects.gnome.org/libchamplain/">http://projects.gnome.org/libchamplain/</ulink>.
</releaseinfo>
<copyright>
- <year>2008,2009</year>
- <holder>Pierre-Luc Beaudoin <pierre-luc pierlux com></holder>
+ <year>2008, 2009</year>
+ <holder>libchamplain contributors</holder>
</copyright>
<legalnotice>
<para>
diff --git a/docs/reference/libchamplain-sections.txt b/docs/reference/libchamplain-sections.txt
index 50ffc8f..e57c723 100644
--- a/docs/reference/libchamplain-sections.txt
+++ b/docs/reference/libchamplain-sections.txt
@@ -362,7 +362,7 @@ champlain_point_get_type
<TITLE>ChamplainCache</TITLE>
ChamplainCache
ChamplainCacheClass
-champlain_cache_get_default
+champlain_cache_dup_default
champlain_cache_fill_tile
champlain_cache_dup_default
champlain_cache_get_size_limit
@@ -395,7 +395,6 @@ champlain_map_source_desc_copy
champlain_map_source_desc_free
champlain_map_source_desc_get_type
champlain_map_source_desc_new
-champlain_map_source_factory_get_default
champlain_map_source_factory_get_list
<SUBSECTION Standard>
CHAMPLAIN_MAP_SOURCE_FACTORY
@@ -430,7 +429,6 @@ champlain_polygon_set_stroke_width
champlain_polygon_show
champlain_polygon_hide
<SUBSECTION Standard>
-CHAMPLAIN_POLYGON_FACTORY
CHAMPLAIN_IS_POLYGON
CHAMPLAIN_TYPE_POLYGON
champlain_polygon_get_type
@@ -445,17 +443,16 @@ CHAMPLAIN_POLYGON_GET_CLASS
ChamplainSelectionMode
ChamplainSelectionLayer
champlain_selection_layer_new
-champlain_selection_layer_get_selected
-champlain_selection_layer_get_selected_markers
-champlain_selection_layer_count_selected_markers
+champlain_selection_layer_set_selection_mode
+champlain_selection_layer_get_selection_mode
champlain_selection_layer_select
champlain_selection_layer_unselect
-champlain_selection_layer_marker_is_selected
champlain_selection_layer_select_all
champlain_selection_layer_unselect_all
-champlain_selection_layer_get_selection_mode
-champlain_selection_layer_set_selection_mode
-champlain_selection_mode_get_type
+champlain_selection_layer_marker_is_selected
+champlain_selection_layer_get_selected
+champlain_selection_layer_get_selected_markers
+champlain_selection_layer_count_selected_markers
<SUBSECTION Standard>
CHAMPLAIN_IS_SELECTION_LAYER
CHAMPLAIN_IS_SELECTION_LAYER_CLASS
diff --git a/docs/reference/libchamplain.types b/docs/reference/libchamplain.types
index b2c5267..58a1bd0 100644
--- a/docs/reference/libchamplain.types
+++ b/docs/reference/libchamplain.types
@@ -4,6 +4,7 @@ champlain_view_get_type
champlain_base_marker_get_type
champlain_marker_get_type
champlain_layer_get_type
+champlain_selection_layer_get_type
champlain_map_source_get_type
champlain_network_map_source_get_type
champlain_tile_get_type
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]
diff --git a/champlain/champlain-selection-layer.c b/champlain/champlain-selection-layer.c
index 7ffc217..3586b79 100644
--- a/champlain/champlain-selection-layer.c
+++ b/champlain/champlain-selection-layer.c
@@ -137,6 +137,9 @@ api_select (ChamplainSelectionLayer *layer,
if (champlain_selection_layer_marker_is_selected (layer, marker))
return;
+ if (layer->priv->mode == CHAMPLAIN_SELECTION_NONE)
+ return;
+
if (layer->priv->mode == CHAMPLAIN_SELECTION_SINGLE)
{
/* Clear previous selection */
@@ -154,6 +157,9 @@ mouse_select (ChamplainSelectionLayer *layer,
{
DEBUG ("Mouse select %p", marker);
+ if (layer->priv->mode == CHAMPLAIN_SELECTION_NONE)
+ return;
+
if (layer->priv->mode == CHAMPLAIN_SELECTION_SINGLE)
{
/* Clear previous selection */
@@ -226,7 +232,7 @@ champlain_selection_layer_init (ChamplainSelectionLayer *self)
/**
* champlain_selection_layer_new:
*
- * Returns a new #ChamplainSelectionLayer ready to be used as a #ClutterContainer for the markers.
+ * Returns: a new #ChamplainSelectionLayer ready to be used as a #ClutterContainer for the markers.
*
* Since: 0.4
*/
@@ -241,7 +247,7 @@ champlain_selection_layer_new ()
*
* This function will return NULL if in CHAMPLAIN_SELETION_MULTIPLE.
*
- * Returns the selected #ChamplainBaseMarker or NULL if none is selected.
+ * Returns: the selected #ChamplainBaseMarker or NULL if none is selected.
*
* Since: 0.4
*/
@@ -260,7 +266,7 @@ champlain_selection_layer_get_selected (ChamplainSelectionLayer *layer)
/**
* champlain_selection_get_selected_markers:
*
- * Returns the list of selected #ChamplainBaseMarker or NULL if none is selected.
+ * Returns: the list of selected #ChamplainBaseMarker or NULL if none is selected.
* You shouldn't free that list.
*
* Since: 0.4
@@ -274,7 +280,7 @@ champlain_selection_layer_get_selected_markers (ChamplainSelectionLayer *layer)
/**
* champlain_selection_layer_count_selected_markers:
*
- * Returns the number of selected #ChamplainBaseMarker
+ * Returns: the number of selected #ChamplainBaseMarker
*
* Since: 0.4
*/
@@ -284,13 +290,30 @@ champlain_selection_layer_count_selected_markers (ChamplainSelectionLayer *layer
return g_list_length (layer->priv->selection);
}
-void
+/**
+ * champlain_selection_layer_select:
+ * @layer: a #ChamplainSelectionLayer
+ * @marker: a #ChamplainBaseMarker
+ *
+ * Selects the marker.
+ *
+ * Since: 0.4
+ */
+void
champlain_selection_layer_select (ChamplainSelectionLayer *layer,
ChamplainBaseMarker *marker)
{
api_select (layer, marker);
}
+/**
+ * champlain_selection_layer_unselect_all:
+ * @layer: a #ChamplainSelectionLayer
+ *
+ * Unselects all markers.
+ *
+ * Since: 0.4
+ */
void
champlain_selection_layer_unselect_all (ChamplainSelectionLayer *layer)
{
@@ -308,6 +331,7 @@ champlain_selection_layer_unselect_all (ChamplainSelectionLayer *layer)
/**
* champlain_selection_layer_select_all:
+ * @layer: a #ChamplainSelectionLayer
*
* Selects all markers in the layer. This call will only work if the selection
* mode is set CHAMPLAIN_SELETION_MULTIPLE.
@@ -320,6 +344,9 @@ champlain_selection_layer_select_all (ChamplainSelectionLayer *layer)
gint n_children = 0;
gint i = 0;
+ if (layer->priv->mode == CHAMPLAIN_SELECTION_NONE)
+ return;
+
if (layer->priv->mode == CHAMPLAIN_SELECTION_SINGLE)
return;
@@ -336,6 +363,15 @@ champlain_selection_layer_select_all (ChamplainSelectionLayer *layer)
}
}
+/**
+ * champlain_selection_layer_unselect:
+ * @layer: a #ChamplainSelectionLayer
+ * @marker: a #ChamplainBaseMarker
+ *
+ * Unselect the marker.
+ *
+ * Since: 0.4
+ */
void
champlain_selection_layer_unselect (ChamplainSelectionLayer *layer,
ChamplainBaseMarker *marker)
@@ -352,6 +388,15 @@ champlain_selection_layer_unselect (ChamplainSelectionLayer *layer,
}
}
+/**
+ * champlain_selection_layer_marker_is_selected:
+ * @layer: a #ChamplainSelectionLayer
+ * @marker: a #ChamplainBaseMarker
+ *
+ * Returns: whether the marker is selected or not.
+ *
+ * Since: 0.4
+ */
gboolean
champlain_selection_layer_marker_is_selected (ChamplainSelectionLayer *layer,
ChamplainBaseMarker *marker)
@@ -368,8 +413,9 @@ champlain_selection_layer_marker_is_selected (ChamplainSelectionLayer *layer,
* @mode: a #ChamplainSelectionMode value
*
* Sets the selection mode of the layer.
* NOTE: changing selection mode to CHAMPLAIN_SELECTION_SINGLE will clear all
* previously selected markers.
*
* Since: 0.4
*/
@@ -384,7 +430,8 @@ champlain_selection_layer_set_selection_mode (ChamplainSelectionLayer *layer,
layer->priv->mode = mode;
/* Switching to single mode shouldn't keep the selection */
- if (mode == CHAMPLAIN_SELECTION_SINGLE)
+ if (mode == CHAMPLAIN_SELECTION_NONE ||
+ mode == CHAMPLAIN_SELECTION_SINGLE)
champlain_selection_layer_unselect_all (layer);
g_object_notify (G_OBJECT (layer), "selection-mode");
@@ -394,7 +441,7 @@ champlain_selection_layer_set_selection_mode (ChamplainSelectionLayer *layer,
* champlain_selection_layer_get_selection_mode:
* @layer: a #ChamplainSelectionLayer
*
- * Returns the selection mode of the layer.
+ * Returns: the selection mode of the layer.
*
* Since: 0.4
*/
@@ -368,8 +413,9 @@ champlain_selection_layer_marker_is_selected (ChamplainSelectionLayer *layer,
*
* Sets the selection mode of the layer.
- * NOTE: changing selection mode to CHAMPLAIN_SELECTION_SINGLE will clear all
- * previously selected markers.
+ *
+ * NOTE: changing selection mode to CHAMPLAIN_SELECTION_NONE or
+ * CHAMPLAIN_SELECTION_SINGLE will clear all previously selected markers.
*
* Since: 0.4